==> vrealize_6_ansible-0.0.157.tar.gz: vrealize_6_ansible-0.0.157/vrealize_6_ansible/vraresource.py <==
#!/usr/bin/python
__author__ = 'Piotr Matuszczyk <piotr.matuszczyk@sap.com>'

class Vraresourceregistry(type):
  def __iter__(self, cls):
    return iter(cls._registry)

class Vraresource(object):
  __metaclass__ = Vraresourceregistry
  _registry = []
  def __init__(self):
    self._registry.append(self)
  name = None
  id = None
  type = None
  description = None
  status = None
  catalogid = None
  requestid = None
  owner = None
  createdate =  None
  updatedate = None
  childs = []
  actionids = []
  network = []
  memory = None
  guestos = None
  cpu = None
  reservationname = None
  extrefid = None
  hostgroup = None
  
  def unmarshalling(self, j):
    self.id = j['id']
    self.name = j['name']
    if j['resourceTypeRef']['label'] == 'Virtual Machine':
      self.type = 'vm'
    elif j['resourceTypeRef']['label'] == 'Multi-Machine Service':
      self.type = 'multitier'
    self.description = j['description']
    self.status = j['status']
    self.catalogid = j['catalogItem']['id']
    self.requestid = j['requestId']
    self.owner = j['owners']['value']
    self.createdate = j['dateCreated']
    self.updatedate = j['lastUpdated']
    #TO DO childs for tier
    for i in j['operations']:
      self.actionids.append({i['name'].replace(" ","").lower(): i['id']})
    for i in j['resourceData']['entries']:
      if i['key'] == 'NETWORK_LIST':
        for n in i['value']['items']['values']['entries']:
          if n['key'] == 'NETWORK_ADDRESS':
            self.network.append({'ipaddress': n['value']['value']})
          elif n['key'] == 'NETWORK_MAC_ADDRESS':
            self.network.append({'macaddress': n['value']['value']})
          elif n['key'] == 'NETWORK_NAME':
            self.network.append({'name': n['value']['value']})
      elif i['key'] == 'MachineMemory':
        self.memory = i['value']['value']
      elif i['key'] == 'MachineGuestOperatingSystem':
        self.guestos = i['value']['value']
      elif i['key'] == 'MachineCPU':
        self.cpu = i['value']['value']
      elif i['key'] == 'MachineReservationName':
        self.reservationname = i['value']['value']
      elif i['key'] == 'EXTERNAL_REFERENCE_ID':
        self.extrefid = i['value']['value']
    self.hostgroup = j['name'].split('-')[-2]

==> vrealize_6_ansible-0.0.164.tar.gz: vrealize_6_ansible-0.0.164/vrealize_6_ansible/vraresource.py <==
#!/usr/bin/python
__author__ = 'Piotr Matuszczyk <piotr.matuszczyk@sap.com>'

class Vraresource(object):
  _registry = []
  def __init__(self):
    self._registry.append(self)
  name = None
  id = None
  type = None
  description = None
  status = None
  catalogid = None
  requestid = None
  owner = None
  createdate =  None
  updatedate = None
  childids = []
  actionids = []
  network = {}
  memory = None
  cpu = None
  reservationname = None
  extrefid = None
  hostgroup = None
  
  def unmarshalling(self, j):
    self.id = j['id']
    self.name = j['name']
    if j['resourceTypeRef']['label'] == 'Virtual Machine':
      self.type = 'vm'
    elif j['resourceTypeRef']['label'] == 'Multi-Machine Service':
      self.type = 'multitier'
    self.description = j['description']
    self.status = j['status']
    self.catalogid = j['catalogItem']['id']
    self.requestid = j['requestId']
    for i in j['owners']:
      self.owner = i['value']
    self.createdate = j['dateCreated']
    self.updatedate = j['lastUpdated']
    #TO DO childids for tier
    for i in j['operations']:
      self.actionids.append({i['name'].replace(" ","").lower(): i['id']})
    for i in j['resourceData']['entries']:
      if i['key'] == 'NETWORK_LIST':
        for m in i['value']['items']:
          for n in m['values']['entries']:
            if n['key'] == 'NETWORK_ADDRESS':
              self.network['ipaddress'] = n['value']['value']
            elif n['key'] == 'NETWORK_MAC_ADDRESS':
              self.network['macaddress'] = n['value']['value']
            elif n['key'] == 'NETWORK_NAME':
              self.network['name'] = n['value']['value']
      elif i['key'] == 'MachineMemory':
        self.memory = i['value']['value']
      elif i['key'] == 'MachineCPU':
        self.cpu = i['value']['value']
      elif i['key'] == 'MachineReservationName':
        self.reservationname = i['value']['value']
      elif i['key'] == 'EXTERNAL_REFERENCE_ID':
        self.extrefid = i['value']['value']
    self.hostgroup = j['name'].split('-')[-2]
